@@ -81,10 +81,11 @@ void ResourceTests::newTag()
     QVERIFY(model->containsAnyStatement(uri, NAO::created(), Soprano::Node()));
     QVERIFY(model->containsAnyStatement(uri, RDF::type(), NAO::Tag()));
     QVERIFY(model->containsAnyStatement(uri, NAO::identifier(), Soprano::LiteralValue("Test")));
+    QVERIFY(model->containsAnyStatement(uri, NAO::prefLabel(), Soprano::LiteralValue::createPlainLiteral("Test")));
 
     QList<Soprano::Statement> stList = model->listStatements( tag.uri(), Soprano::Node(),
                                                               Soprano::Node() ).allStatements();
-    QCOMPARE(stList.size(), 4);
+    QCOMPARE(stList.size(), 5);
 }
 
 void ResourceTests::newContact()
@@ -404,6 +405,7 @@ void ResourceTests::tagsUpdate()
     QVERIFY(tag3.exists());
 
     Resource res(resUri);
+    res.setWatchEnabled( true );
 
     QList<Tag> tags;
     tags << tag1 << tag2 << tag3;
@@ -486,6 +488,7 @@ void ResourceTests::newResourcesUpdated()
     QUrl fileUri;
 
     Resource fileRes( fileUrl );
+    fileRes.setWatchEnabled( true );
     QVERIFY(!fileRes.exists());
     QVERIFY(fileRes.uri().isEmpty());
 
@@ -505,6 +508,7 @@ void ResourceTests::newResourcesUpdated()
 void ResourceTests::identifierUpdate()
 {
     Tag tag("Fire");
+    tag.setWatchEnabled( true );
     QVERIFY(!tag.exists());
 
     // Save the tag
@@ -538,15 +542,15 @@ void ResourceTests::urlUpdate()
 
     Resource res;
     res.setProperty(NIE::url(), resUrl);
+    res.setWatchEnabled(true);
 
     QVERIFY(res.exists());
     QVERIFY(!res.uri().isEmpty());
 
-    QUrl resUrl2("akonadi:?item=2342");
+    QUrl resUrl2("akonadi:?item=50000");
     KJob* job = Nepomuk2::setProperty( QList<QUrl>() << res.uri(), NIE::url(),
                                        QVariantList() << resUrl2 );
     job->exec();
-    QEXPECT_FAIL("", "You currently aren't allowed to change the nie:url", Abort);
     QVERIFY(!job->error());
 
     QTest::qWait( 200 );
@@ -554,8 +558,10 @@ void ResourceTests::urlUpdate()
     QUrl nieUrl = res.property(NIE::url()).toUrl();
     QCOMPARE(nieUrl, resUrl2);
 
+    QVERIFY(res.exists());
+
     Resource res2(resUrl);
-    QVERIFY(!res.exists());
+    QVERIFY(!res2.exists());
 
     Resource res3(resUrl2);
     QVERIFY(res3.exists());
@@ -569,12 +575,20 @@ void ResourceTests::resourceDeletion()
     const QUrl fileUrl(tempFile.fileName());
 
     Tag tag("Poop");
+    tag.setWatchEnabled(true);
+
     Resource fileRes( fileUrl );
+    fileRes.setWatchEnabled(true);
     fileRes.addTag(tag);
 
     const QUrl tagUri = tag.uri();
     QCOMPARE(fileRes.tags(), QList<Tag>() << tag);
 
+    // This 200 is because there is a slight delay after the watcher is first created
+    // and after it comes into use
+    // FIXME: Find a solution?
+    QTest::qWait(200);
+
     QVERIFY(tag.exists());
     tag.remove();
     QVERIFY(!tag.exists());
@@ -589,6 +603,45 @@ void ResourceTests::resourceDeletion()
     QVERIFY(!model->containsAnyStatement(QUrl(), QUrl(), tagUri));
 }
 
+void ResourceTests::resourceDeletion2()
+{
+    KTemporaryFile tempFile;
+    QVERIFY(tempFile.open());
+    const QUrl fileUrl(tempFile.fileName());
+
+    Tag tag("Poop");
+    tag.setWatchEnabled(true);
+
+    Resource fileRes( fileUrl );
+    fileRes.setWatchEnabled(true);
+    fileRes.addTag(tag);
+
+    const QUrl tagUri = tag.uri();
+    QCOMPARE(fileRes.tags(), QList<Tag>() << tag);
+
+    // This 200 is because there is a slight delay after the watcher is first created
+    // and after it comes into use
+    // FIXME: Find a solution?
+    QTest::qWait(200);
+
+    QVERIFY(tag.exists());
+
+    KJob* job = Nepomuk2::removeResources( QList<QUrl>() << tag.uri() );
+    job->exec();
+    QVERIFY(!job->error());
+
+    QTest::qWait(200);
+
+    QVERIFY(!tag.exists());
+    QVERIFY(tag.uri().isEmpty());
+
+    QVERIFY(fileRes.tags().isEmpty());
+
+    // Verify the statements
+    Soprano::Model* model = ResourceManager::instance()->mainModel();
+    QVERIFY(!model->containsAnyStatement(tagUri, QUrl(), QUrl()));
+    QVERIFY(!model->containsAnyStatement(QUrl(), QUrl(), tagUri));
+}
 
 }
 
