@@ -19,6 +19,7 @@
 
 
 #include "jobmodel.h"
+#include "cleaningjob.h"
 #include "cleaningjobs.h"
 
 #include <KIcon>
@@ -27,6 +28,8 @@
 
 #include "resourcemanager.h"
 
+using namespace Nepomuk2;
+
 JobModel::JobModel(QObject* parent): QAbstractListModel(parent)
 {
     // Forcibly initializing the ResourceManager so that it gets initialized
