@@ -75,17 +75,6 @@ Nepomuk2::IndexCleaner::IndexCleaner(QObject* parent)
       m_delay(0)
 {
     setCapabilities( Suspendable );
-
-    KConfig config("nepomukstrigirc");
-    KConfigGroup generalGrp = config.group( "general" );
-    m_supportLegacyData = generalGrp.readEntry( "legacyCleaning", true );
-
-    QString query = QString::fromLatin1("ask where { ?g <http://www.strigi.org/fields#indexGraphFor> ?r . }");
-    Soprano::Model* model = ResourceManager::instance()->mainModel();
-    m_supportStrigiGraphData = model->executeQuery( query, Soprano::Query::QueryLanguageSparqlNoInference ).boolValue();
-
-    kDebug() << "LegacyData: " << m_supportLegacyData;
-    kDebug() << "StrigiGraphData: " << m_supportStrigiGraphData;
 }
 
 
@@ -129,22 +118,7 @@ void Nepomuk2::IndexCleaner::start()
 
 
     //
-    // 2. (legacy data) We query all files that should not be in the store.
-    // This for example excludes all filex:/ URLs.
-    //
-    if( m_supportStrigiGraphData ) {
-        m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
-                                                "?r nie:url ?url . "
-                                                "?g <http://www.strigi.org/fields#indexGraphFor> ?r . "
-                                                "FILTER(REGEX(STR(?url),'^file:/')) . "
-                                                "%2 } LIMIT %3" )
-                            .arg( folderFilter )
-                            .arg(limit);
-    }
-
-
-    //
-    // 3. Build filter query for all exclude filters
+    // 2. Build filter query for all exclude filters
     //
     const QString fileFilters = constructExcludeFiltersFilenameFilter(Nepomuk2::FileIndexerConfig::self());
     const QString includeExcludeFilters = constructExcludeIncludeFoldersFilter(Nepomuk2::FileIndexerConfig::self()->includeFolders());
@@ -158,7 +132,7 @@ void Nepomuk2::IndexCleaner::start()
         filters = QString::fromLatin1("FILTER(%1) .").arg( includeExcludeFilters );
 
     if(!filters.isEmpty()) {
-        // 3.1. Data for files which are excluded through filters
+        // 2.1. Data for files which are excluded through filters
         if(!appRes.isEmpty()) {
             m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
                                                      "graph ?g { ?r nie:url ?url . } . "
@@ -170,21 +144,9 @@ void Nepomuk2::IndexCleaner::start()
                                       filters )
                                 .arg(limit);
         }
-
-        // 3.2. (legacy data) Data for files which are excluded through filters
-        if( m_supportStrigiGraphData ) {
-            m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
-                                                    "?r nie:url ?url . "
-                                                    "?r nfo:fileName ?fn . "
-                                                    "?g <http://www.strigi.org/fields#indexGraphFor> ?r . "
-                                                    "FILTER(REGEX(STR(?url),\"^file:/\")) . "
-                                                    "%1 } LIMIT %2" )
-                                .arg( filters )
-                                .arg(limit);
-        }
     }
 
-    // 3.3. Data for files which have paths that are excluded through exclude filters
+    // 2.2. Data for files which have paths that are excluded through exclude filters
     const QString excludeFiltersFolderFilter = constructExcludeFiltersFolderFilter(Nepomuk2::FileIndexerConfig::self());
     if(!excludeFiltersFolderFilter.isEmpty()) {
         m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
@@ -195,56 +157,6 @@ void Nepomuk2::IndexCleaner::start()
                             .arg( Soprano::Node::resourceToN3( appRes ),
                                   excludeFiltersFolderFilter )
                             .arg(limit);
-
-        // 3.4. (legacy data) Data for files which have paths that are excluded through exclude filters
-        if( m_supportStrigiGraphData ) {
-            m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
-                                                    "?r nie:url ?url . "
-                                                    "?g <http://www.strigi.org/fields#indexGraphFor> ?r . "
-                                                    "FILTER(REGEX(STR(?url),\"^file:/\") && %1) . "
-                                                    "} LIMIT %2" )
-                                .arg( excludeFiltersFolderFilter)
-                                .arg(limit);
-        }
-    }
-
-    if( m_supportLegacyData ) {
-        //
-        // 4. (legacy data) Remove all old data from Xesam-times. While we leave out the data created by libnepomuk
-        // there is no problem since libnepomuk still uses backwards compatible queries and we use
-        // libnepomuk to determine URIs in the strigi backend.
-        //
-        m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
-                                                "?r <http://strigi.sf.net/ontologies/0.9#parentUrl> ?p1 . } LIMIT %1" )
-                            .arg(limit);
-        m_removalQueries << QString::fromLatin1( "select distinct ?r where { "
-                                                "?r %1 ?u2 . } LIMIT %2" )
-                            .arg( Soprano::Node::resourceToN3( Soprano::Vocabulary::Xesam::url() ) )
-                            .arg(limit);
-
-
-        //
-        // 5. (legacy data) Remove data which is useless but still around from before. This could happen due to some buggy version of
-        // the indexer or the filewatch service or even some application messing up the data.
-        // We look for indexed files that do not have a nie:url defined and thus, will never be caught by any of the
-        // other queries. In addition we check for an isPartOf relation since strigi produces EmbeddedFileDataObjects
-        // for video and audio streams.
-        //
-        m_removalQueries << QString::fromLatin1("select ?r where { "
-                                                "graph ?g { ?r ?pp ?oo . } . "
-                                                "?g <http://www.strigi.org/fields#indexGraphFor> ?r . "
-                                                "FILTER NOT EXISTS { ?r nie:url ?u . } . "
-                                                "FILTER NOT EXISTS { ?r nie:isPartOf ?p . } . "
-                                                "} LIMIT %1")
-                            .arg(limit);
-
-
-        m_removalQueries << QString::fromLatin1("select ?r where {"
-                                                " ?g <http://www.strigi.org/fields#indexGraphFor> ?r ."
-                                                " ?r nie:isPartOf ?f ."
-                                                " FILTER(!REGEX(STR(?f), '^nepomuk:/res/')) . "
-                                                " } LIMIT %1")
-                            .arg(limit);
     }
 
     //
@@ -290,11 +202,6 @@ void Nepomuk2::IndexCleaner::clearNextBatch()
     }
 
     else {
-        if( m_supportLegacyData ) {
-            KConfig config("nepomukstrigirc");
-            KConfigGroup generalGrp = config.group( "general" );
-            generalGrp.writeEntry( "legacyCleaning", false );
-        }
         emitResult();
     }
 }
@@ -338,7 +245,9 @@ namespace {
             subFilters << constructFolderSubFilter( folders, index );
         }
 
-        QString thisFilter = QString::fromLatin1( "REGEX(STR(?url),'^%1')" ).arg( QString::fromAscii( KUrl( path ).toEncoded() ) );
+        QString str = QString::fromLatin1( KUrl(path).toEncoded() );
+        str.replace( '\'', QLatin1String("\\'") );
+        QString thisFilter = QString::fromLatin1( "REGEX(STR(?url),'^%1')" ).arg( str );
 
         // we want all folders that should NOT be indexed
         if ( include ) {
