@@ -43,8 +43,10 @@
 
 
 Nepomuk2::IndexScheduler::IndexScheduler( QObject* parent )
-    : QObject( parent ),
-      m_indexing( false )
+    : QObject( parent )
+    , m_indexing( false )
+    , m_lastBasicIndexingFile( QDateTime::currentDateTime() )
+    , m_basicIndexingFileCount( 0 )
 {
     // remove old indexing error log
     if(FileIndexerConfig::self()->isDebugModeEnabled()) {
@@ -72,9 +74,11 @@ Nepomuk2::IndexScheduler::IndexScheduler( QObject* parent )
     m_fileIQ = new FileIndexingQueue( this );
 
     connect( m_basicIQ, SIGNAL(finishedIndexing()), this, SIGNAL(basicIndexingDone()) );
+    connect( m_fileIQ, SIGNAL(finishedIndexing()), this, SIGNAL(fileIndexingDone()) );
 
     connect( m_basicIQ, SIGNAL(beginIndexingFile(QUrl)), this, SLOT(slotBeginIndexingFile(QUrl)) );
     connect( m_basicIQ, SIGNAL(endIndexingFile(QUrl)), this, SLOT(slotEndIndexingFile(QUrl)) );
+    connect( m_basicIQ, SIGNAL(endIndexingFile(QUrl)), this, SLOT(slotEndBasicIndexingFile()) );
     connect( m_fileIQ, SIGNAL(beginIndexingFile(QUrl)), this, SLOT(slotBeginIndexingFile(QUrl)) );
     connect( m_fileIQ, SIGNAL(endIndexingFile(QUrl)), this, SLOT(slotEndIndexingFile(QUrl)) );
 
@@ -87,15 +91,11 @@ Nepomuk2::IndexScheduler::IndexScheduler( QObject* parent )
     connect( m_basicIQ, SIGNAL(endIndexingFile(QUrl)), m_fileIQ, SLOT(enqueue(QUrl)) );
 
     // Status String
-    connect( m_basicIQ, SIGNAL(beginIndexingFile(QUrl)), this, SIGNAL(statusStringChanged()) );
-    connect( m_basicIQ, SIGNAL(endIndexingFile(QUrl)), this, SIGNAL(statusStringChanged()) );
-    connect( m_basicIQ, SIGNAL(startedIndexing()), this, SIGNAL(statusStringChanged()) );
-    connect( m_basicIQ, SIGNAL(finishedIndexing()), this, SIGNAL(statusStringChanged()) );
-    connect( m_fileIQ, SIGNAL(beginIndexingFile(QUrl)), this, SIGNAL(statusStringChanged()) );
-    connect( m_fileIQ, SIGNAL(endIndexingFile(QUrl)), this, SIGNAL(statusStringChanged()) );
-    connect( m_fileIQ, SIGNAL(startedIndexing()), this, SIGNAL(statusStringChanged()) );
-    connect( m_fileIQ, SIGNAL(finishedIndexing()), this, SIGNAL(statusStringChanged()) );
-    connect( this, SIGNAL(indexingSuspended(bool)), this, SIGNAL(statusStringChanged()) );
+    connect( m_basicIQ, SIGNAL(startedIndexing()), this, SLOT(emitStatusStringChanged()) );
+    connect( m_basicIQ, SIGNAL(finishedIndexing()), this, SLOT(emitStatusStringChanged()) );
+    connect( m_fileIQ, SIGNAL(startedIndexing()), this, SLOT(emitStatusStringChanged()) );
+    connect( m_fileIQ, SIGNAL(finishedIndexing()), this, SLOT(emitStatusStringChanged()) );
+    connect( this, SIGNAL(indexingSuspended(bool)), this, SLOT(emitStatusStringChanged()) );
 
     m_eventMonitor = new EventMonitor( this );
     connect( m_eventMonitor, SIGNAL(diskSpaceStatusChanged(bool)),
@@ -108,21 +108,6 @@ Nepomuk2::IndexScheduler::IndexScheduler( QObject* parent )
     m_cleaner = new IndexCleaner(this);
     connect( m_cleaner, SIGNAL(finished(KJob*)), this, SLOT(slotCleaningDone()) );
 
-    // Special settings for the queues
-    KConfig config( "nepomukstrigirc" );
-    KConfigGroup cfg = config.group( "Indexing" );
-
-    int basicIQDelay = cfg.readEntry<int>( "BasicIQDelay", 0 );
-    int fileIQDelay = cfg.readEntry<int>( "FileIQDelay", 0 );
-    m_basicIQ->setDelay( basicIQDelay );
-    m_fileIQ->setDelay( fileIQDelay );
-
-    QString value = cfg.readEntry<QString>( "NormalMode_FileIndexing", "suspend" );
-    if( value == "suspend" )
-        m_shouldSuspendFileIQOnNormal = true;
-    else if( value == "resume" )
-        m_shouldSuspendFileIQOnNormal = false;
-
     m_state = State_Normal;
     slotScheduleIndexing();
 }
@@ -315,15 +300,9 @@ void Nepomuk2::IndexScheduler::analyzeFile( const QString& path )
 }
 
 
-void Nepomuk2::IndexScheduler::slotBeginIndexingFile(const QUrl& url)
+void Nepomuk2::IndexScheduler::slotBeginIndexingFile(const QUrl&)
 {
     setIndexingStarted( true );
-
-    QString path = url.toLocalFile();
-    if( QFileInfo(path).isDir() )
-        emit indexingFolder( path );
-    else
-        emit indexingFile( path );
 }
 
 void Nepomuk2::IndexScheduler::slotEndIndexingFile(const QUrl&)
@@ -336,6 +315,37 @@ void Nepomuk2::IndexScheduler::slotEndIndexingFile(const QUrl&)
     }
 }
 
+//
+// Slow down the Basic Indexing if we have > x files
+//
+void Nepomuk2::IndexScheduler::slotEndBasicIndexingFile()
+{
+    QDateTime current = QDateTime::currentDateTime();
+    if( current.secsTo(m_lastBasicIndexingFile) > 60 ) {
+        m_basicIQ->setDelay( 0 );
+        m_basicIndexingFileCount = 0;
+    }
+    else {
+        if ( m_basicIndexingFileCount > 1000 ) {
+            m_basicIQ->setDelay( 400 );
+        }
+        else if ( m_basicIndexingFileCount > 750 ) {
+            m_basicIQ->setDelay( 300 );
+        }
+        else if ( m_basicIndexingFileCount > 500 ) {
+            m_basicIQ->setDelay( 200 );
+        }
+        else if ( m_basicIndexingFileCount > 200 ) {
+            m_basicIQ->setDelay( 100 );
+        }
+        else
+            m_basicIQ->setDelay( 0 );
+    }
+
+    m_basicIndexingFileCount++;
+}
+
+
 void Nepomuk2::IndexScheduler::slotTeardownRequested(const Nepomuk2::RemovableMediaCache::Entry* entry)
 {
     const QString path = entry->mountPath();
@@ -344,7 +354,6 @@ void Nepomuk2::IndexScheduler::slotTeardownRequested(const Nepomuk2::RemovableMe
     m_fileIQ->clear( path );
 }
 
-
 void Nepomuk2::IndexScheduler::slotScheduleIndexing()
 {
     if( m_state == State_Suspended ) {
@@ -375,7 +384,9 @@ void Nepomuk2::IndexScheduler::slotScheduleIndexing()
         kDebug() << "Battery";
         m_state = State_OnBattery;
 
+        m_basicIQ->setDelay(0);
         m_basicIQ->resume();
+
         m_fileIQ->suspend();
         if( m_cleaner )
             m_cleaner->suspend();
@@ -390,7 +401,10 @@ void Nepomuk2::IndexScheduler::slotScheduleIndexing()
         }
         else {
             m_state = State_UserIdle;
+            m_basicIQ->setDelay( 0 );
             m_basicIQ->resume();
+
+            m_fileIQ->setDelay( 0 );
             m_fileIQ->resume();
         }
     }
@@ -399,20 +413,11 @@ void Nepomuk2::IndexScheduler::slotScheduleIndexing()
         kDebug() << "Normal";
         m_state = State_Normal;
 
+        m_basicIQ->setDelay( 0 );
         m_basicIQ->resume();
-        if( m_shouldSuspendFileIQOnNormal )
-            m_fileIQ->suspend();
-        else {
-            if( m_cleaner ) {
-                // We need to run the cleaner
-                m_state = State_Cleaning;
-                m_cleaner->start();
-                slotScheduleIndexing();
-            }
-            else {
-                m_fileIQ->resume();
-            }
-        }
+
+        m_fileIQ->setDelay( 3000 );
+        m_fileIQ->resume();
     }
 }
 
@@ -427,18 +432,10 @@ QString Nepomuk2::IndexScheduler::userStatusString() const
         return i18nc( "@info:status", "File indexer is suspended." );
     }
     else if ( cleaning ) {
-        // TODO: Change this string for 4.11
-        return i18nc( "@info:status", "Scanning for recent changes in files for desktop search");
+        return i18nc( "@info:status", "Cleaning invalid file metadata");
     }
     else if ( indexing ) {
-        QUrl url = currentUrl();
-
-        if( url.isEmpty() ) {
-            return i18nc( "@info:status", "Indexing files for desktop search." );
-        }
-        else {
-            return i18nc( "@info:status", "Indexing %1", url.toLocalFile() );
-        }
+        return i18nc( "@info:status", "Indexing files for desktop search." );
     }
     else if ( processing ) {
         return i18nc( "@info:status", "Scanning for recent changes in files for desktop search");
@@ -448,6 +445,19 @@ QString Nepomuk2::IndexScheduler::userStatusString() const
     }
 }
 
+Nepomuk2::IndexScheduler::State Nepomuk2::IndexScheduler::currentStatus() const
+{
+    return m_state;
+}
+
+void Nepomuk2::IndexScheduler::emitStatusStringChanged()
+{
+    QString status = userStatusString();
+    if( status != m_oldStatus ) {
+        emit statusStringChanged();
+        m_oldStatus = status;
+    }
+}
 
 
 
